@@ -1,12 +1,11 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2022, by Samuel Williams.
+# Copyright, 2021-2024, by Samuel Williams.
 
 require_relative 'output/default'
-require_relative 'output/json'
-require_relative 'output/text'
-require_relative 'output/xterm'
+require_relative 'output/serialized'
+require_relative 'output/terminal'
 require_relative 'output/null'
 
 module Console
